.. _benchmarking_framework:

Benchmarking Framework
======================

The benchmarking of the SDV Synthetic Data Generators is done using the
`Synthetic Data Gym (SDGym) <https://github.com/sdv-dev/SDGym>`__,
a library from the Synthetic Data Vault Project that offers a collection of
tools to run synthetic data generators in a large collection of datasets
and then apply the metrics from our :ref:`evaluation_framework` to assess how
good the generated data is.

.. toctree::
    :titlesonly:

    install
    docker
    synthesizers
    datasets
    run
